#! /bin/sh

this_dir=`pwd`
SNAPSHOT=`date +-"%y%m%d"`

cd ../../../../

aclocal
autoconf
automake
./configure --disable-debugging
make dist

mv ApacheJServ-1.1.2.tar.gz \
$this_dir/ApacheJServ-1.1.2${SNAPSHOT}.tar.gz

cd $this_dir

